package org.rcisoft.util;

import cn.afterturn.easypoi.excel.ExcelExportUtil;
import cn.afterturn.easypoi.excel.entity.ExportParams;
import cn.afterturn.easypoi.excel.entity.enmus.ExcelType;
import cn.afterturn.easypoi.excel.entity.params.ExcelExportEntity;
import cn.afterturn.easypoi.excel.export.ExcelExportService;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.util.CyEpExcelUtil;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.net.URLEncoder;
import java.util.List;
import java.util.Map;

/**
 * @Author: gy
 * @Date: 2024/4/20 12:57
 * @Description: 动态列导出（非注解形式）
 */
@Slf4j
public class ExportToExcelUtil  extends CyEpExcelUtil {
    // 导出动态列
    /**
     * entityList 表头
     * dataList 数据集合
     * **/
    public static void exportExcel(HttpServletResponse response, List<ExcelExportEntity> entityList, List<Map<String, Object>> dataList) {
        // 1、创建一个Workbook（XSSFWorkbook）
        Workbook workbook = new XSSFWorkbook();
        // 3、定义标题和sheetName
        ExportParams exportParams = new ExportParams();
        exportParams.setStyle(ExcelExportStatisticStyler.class);
        // 默认未 ExcelType.HSSF导出失败
        exportParams.setType(ExcelType.XSSF);
        ExcelExportService service = new ExcelExportService();
        service.createSheetForMap(workbook, exportParams, entityList, dataList);
        downLoadExcel("导出统计",response,workbook);

    }

    public static void exportExcel(List<?> list, String title, String sheetName, Class<?> pojoClass, String fileName, HttpServletResponse response) {
        ExportParams exportParams = new ExportParams();
        exportParams.setStyle(ExcelExportStatisticStyler.class);
        String[] format = fileName.split("\\.");
        if (format[1].equals("xlsx")) {
            exportParams.setType(ExcelType.XSSF);
        }

        defaultExport(list, pojoClass, fileName, response, exportParams);
    }

    private static void defaultExport(List<?> list, Class<?> pojoClass, String fileName, HttpServletResponse response, ExportParams exportParams) {
        Workbook workbook = ExcelExportUtil.exportExcel(exportParams, pojoClass, list);
        if (workbook != null) {
            downLoadExcel(fileName, response, workbook);
        }

    }

    // 下载excel
    public static void downLoadExcel(String fileName, HttpServletResponse response, Workbook workbook) {
        ServletOutputStream outputStream = null;

        try {
            response.setCharacterEncoding("UTF-8");
            response.setHeader("content-Type", "application/vnd.ms-excel");
            response.setHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode(fileName, "UTF-8"));
            outputStream = response.getOutputStream();
            workbook.write(outputStream);
        } catch (IOException var12) {
            throw new CyServiceException(var12.getMessage());
        } finally {
            try {
                if (outputStream != null) {
                    outputStream.close();
                }
            } catch (IOException var11) {
                log.info("context:" + var11);
            }

        }

    }
}
